<?php
/**
 * Home_Top widget area
 *
 * @package shark_news
 */
/**
 * Home_Top Widgets class.
 *
 * @since 1.0
 */

class Shark_News_Home_Top_Widgets{

	/**
	 * Number of maximum registered widgets.
	 *
	 * @since 1.0
	 *
	 * @access protected
	 * @var int
	 */
	protected $max_widgets = 0;

	/**
	 * Number of active widgets.
	 *
	 * @since 1.0
	 *
	 * @access protected
	 * @var int
	 */
	protected $active_widgets = 0;

	/**
	 * Prefix to apply hook.
	 *
	 * @since 1.0
	 *
	 * @access protected
	 * @var int
	 */
	protected $theme_prefix = 'shark_news';

	/**
	 * Construcor.
	 *
	 * @since 1.0
	 */
	function __construct() {

		$this->setup();
		$this->init();

	}

	/**
	 * Initial setup.
	 *
	 * @since 1.0
	 */
	function setup() {

		$support = get_theme_support( 'home-top-widgets' );
		if ( empty( $support ) ) {
			return;
		}
		if ( absint( $support[0] ) < 1 ) {
			return;
		}
		$this->max_widgets = absint( $support[0] );
		$this->active_widgets = $this->get_number_of_active_widgets();

	}

	/**
	 * Initialize hooks.
	 *
	 * @since 1.0
	 */
	function init() {

		if ( $this->max_widgets < 1 ) {
			return;
		}

		// Register home_top widgets.
		add_action( 'widgets_init', array( $this, 'home_top_widgets_init' ), 20 );

		if ( $this->active_widgets > 0 ) {
			// Add home_top widgets in front end.
			add_action( $this->theme_prefix . '_home_top_start_action', array( $this, 'add_home_top_widgets' ), 20 );
		}

	}

	/**
	 * Register home_top widgets.
	 *
	 * @since 1.0
	 */
	function home_top_widgets_init() {

		for ( $i = 1; $i <= $this->max_widgets; $i++ ) {
			register_sidebar( array(
				'name'          => sprintf( __( 'Home Top Area %d', 'shark-news' ), $i ),
				'id'            => sprintf( 'home-top-%d', $i ),
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="widget-title">',
				'after_title'   => '</h3>',
			) );
		}

	}

	/**
	 * Returns number of active home_top widgets.
	 *
	 * @since 1.0
	 *
	 * @return int Number of active widgets.
	 */
	private function get_number_of_active_widgets() {

		$count = 0;

		for ( $i = 1; $i <= $this->max_widgets; $i++ ) {
			if ( is_active_sidebar( 'home-top-' . $i ) ) {
				$count++;
			}
		}

		return $count;

	}

	/**
	 * Add home_top widgets content in front end.
	 *
	 * @since 1.0
	 */
	function add_home_top_widgets() {

		$flag_apply_home_top_widgets_content = apply_filters( $this->theme_prefix . '_filter_home_top_widgets', true );
		if ( true !== $flag_apply_home_top_widgets_content ) {
			return false;
		}

		$args = array(
		'container' => 'div',
		'before'    => '<div class="page-section wrapper"><div class="home-top-container">',
		'after'     => '</div>',
		);
		$home_top_widgets_content = $this->get_home_top_widgets_content( $args );
		echo $home_top_widgets_content;

	}

	/**
	 * Returns all active home_top widgets number in array.
	 *
	 * @since 1.0
	 *
	 * @return array Active widgets
	 */
	function all_active_widgets() {

		$arr = array();

		for ( $i = 1; $i <= $this->max_widgets ; $i++ ) {
			if ( is_active_sidebar( 'home-top-' . $i ) ) {
				$arr[] = $i;
			}
		}
		return $arr;

	}

	/**
	 * Returns home_top widget contents.
	 *
	 * @since 1.0
	 *
	 * @param array $args Home_Top widget arguments.
	 */
	function get_home_top_widgets_content( $args ) {

		$number = $this->active_widgets;
		$all_active_widgets = $this->all_active_widgets();

		// Default arguments.
		$args = wp_parse_args( (array) $args, array(
			'container'       => 'div',
			'container_class' => $this->custom_home_top_widget_class( 'home-top-widgets-area' ),
			'container_style' => '',
			'container_id'    => '',
			'wrap_class'      => 'column-wrapper',
			'before'          => '',
			'after'           => '',
		) );
		$args = apply_filters( $this->theme_prefix . '_filter_home_top_widgets_args', $args );

		ob_start();
		$container_open = '';
		$container_close = '';

		if ( ! empty( $args['container_class'] ) || ! empty( $args['container_id'] ) ) {
			$container_open = sprintf(
				'<%s %s %s %s>',
				$args['container'],
				( $args['container_class'] ) ? 'class="' . $args['container_class'] . '"':'',
				( $args['container_id'] ) ? 'id="' . $args['container_id'] . '"':'',
				( $args['container_style'] ) ? 'style="' . esc_attr( $args['container_style'] ) . '"':''
			);
		}
		if ( ! empty( $args['container_class'] ) || ! empty( $args['container_id'] ) ) {
			$container_close = sprintf(
				'</%s>',
				$args['container']
			);
		}

		echo $container_open;

		echo $args['before'];

		for ( $i = 1; $i <= $number; $i++ ) {

			if ( isset( $all_active_widgets[ $i - 1 ] ) ) {
				$div_classes = $args['wrap_class'];
				$div_classes = trim( $div_classes );
				echo '<div class="' . esc_attr( $div_classes ) .  '">';
				$sidebar_name = 'home-top-' . $all_active_widgets[ $i - 1 ];
				dynamic_sidebar( $sidebar_name );
				echo '</div><!-- .' . esc_attr( $args['wrap_class'] ) . ' -->';
			}

		} // End for loop.

		echo $args['after'];

		echo $container_close;

		$output = ob_get_contents();
		ob_end_clean();
		return $output;

	}

	/**
	 * Add custom class in widgets.
	 *
	 * @since 1.0
	 *
	 * @param string $input Class for home_top widget column.
	 */
	function custom_home_top_widget_class( $input ) {

		$home_top_widgets_number = $this->active_widgets;

		$input .= ' widget-column-' . $home_top_widgets_number;

		return $input;

	}
}

// Initialize.
$shark_news_home_top_widgets = new Shark_News_Home_Top_Widgets();
